@@ -1,4 +1,4 @@
-from edps import SCIENCE, QC1_CALIB, QC0
+from edps import SCIENCE, QC1_CALIB, QC0, CALCHECKER
 from edps import task, alternative_associated_inputs
 from .qmost_datasources import *
 from .qmost_rules import *
@@ -104,7 +104,7 @@ master_psf_task = (
   .with_alternative_associated_inputs(master_detector_flat_choices)
   .with_associated_input(master_trace_task, [ fibre_trace_class, fibre_mask_class ],
                          match_rules=match_master_trace_last_week)
-  .with_meta_targets([QC1_CALIB])
+  .with_meta_targets([QC1_CALIB, CALCHECKER])
   .build())
 
 simuarc_task = (
@@ -120,7 +120,7 @@ simuarc_task = (
   .with_associated_input(wave_map_ds)
   .with_associated_input(arc_linelist_ds)
   .with_associated_input(reference_wave_ds, min_ret=0)
-  .with_meta_targets([QC1_CALIB])
+  .with_meta_targets([QC1_CALIB, CALCHECKER])
   .build())
 
 simufpe_task = (
@@ -134,7 +134,7 @@ simufpe_task = (
   .with_associated_input(master_trace_task, [ fibre_trace_class, fibre_mask_class ],
                          match_rules=match_master_trace_last_week)
   .with_associated_input(simuarc_task, [ simuarc_wave_class ])
-  .with_meta_targets([QC1_CALIB])
+  .with_meta_targets([QC1_CALIB, CALCHECKER])
   .build())
 
 master_wave_task = (
@@ -150,7 +150,7 @@ master_wave_task = (
   .with_associated_input(wave_map_ds)
   .with_associated_input(simufpe_task, [ fpe_linelist_class ], match_rules=match_simufpe_last_month)
   .with_associated_input(reference_wave_ds, min_ret=0)
-  .with_meta_targets([QC1_CALIB])
+  .with_meta_targets([QC1_CALIB, CALCHECKER])
   .build())
 
 master_fibre_flat_task = (
@@ -165,7 +165,7 @@ master_fibre_flat_task = (
                          match_rules=match_master_trace_last_week)
   .with_associated_input(master_psf_task, [ master_psf_class ], match_rules=match_master_psf_last_day)
   .with_associated_input(master_wave_task, [ master_wave_class ], match_rules=match_master_wave_last_day)
-  .with_meta_targets([QC1_CALIB])
+  .with_meta_targets([QC1_CALIB, CALCHECKER])
   .build())
 
 # Twilight flat trace.  I'm reluctant to trace these given that this
@@ -217,7 +217,7 @@ sky_fibre_flat_task = (
   .with_associated_input(master_wave_task, [ master_wave_class ], match_rules=match_master_wave_last_day)
   .with_associated_input(master_fibre_flat_task, [ master_fibre_flat_class ],
                          match_rules=match_master_fibre_flat_last_week)
-  .with_meta_targets([QC1_CALIB])
+  .with_meta_targets([QC1_CALIB, CALCHECKER])
   .build())
 
 # OB-level trace.
@@ -232,7 +232,7 @@ ob_trace_task = (
   .with_alternative_associated_inputs(master_detector_flat_choices)
   .with_associated_input(slit_mask_ds)
   .with_associated_input(reference_fibre_trace_ds, min_ret=0)
-  .with_meta_targets([QC0, QC1_CALIB])
+  .with_meta_targets([QC0, QC1_CALIB, CALCHECKER])
   .build())
 
 # Alternative associated input directive used to supply trace for
@@ -260,7 +260,7 @@ ob_fibre_flat_task = (
   .with_associated_input(master_wave_task, [ master_wave_class ], match_rules=match_master_wave_last_day)
   .with_associated_input(master_fibre_flat_task, [ master_fibre_flat_class ],
                          match_rules=match_master_fibre_flat_last_week)
-  .with_meta_targets([QC1_CALIB])
+  .with_meta_targets([QC1_CALIB, CALCHECKER])
   .build())
 
 ob_wave_task = (
@@ -274,10 +274,12 @@ ob_wave_task = (
   .with_alternative_associated_inputs(ob_trace_choices)
   .with_associated_input(simufpe_task, [ fpe_linelist_class ], match_rules=match_simufpe_last_month)
   .with_associated_input(master_wave_task, [ master_wave_class ], match_rules=match_master_wave_last_day)
-  .with_meta_targets([QC0, QC1_CALIB])
+  .with_meta_targets([QC0, QC1_CALIB, CALCHECKER])
   .build())
 
 # Science.
+# Updated to use daytime calibrations instead of nighttime OB-level calibrations
+# (day flats are more stable than night ones see ticket QMOST-1872).
 
 science_task = (
   task("science")
@@ -287,14 +289,13 @@ science_task = (
   .with_alternative_associated_inputs(master_bias_choices)
   .with_alternative_associated_inputs(master_dark_choices)
   .with_alternative_associated_inputs(master_detector_flat_choices)
-  .with_alternative_associated_inputs(ob_trace_choices)
+  .with_associated_input(master_trace_task, [ fibre_trace_class, fibre_mask_class ],
+                         match_rules=match_master_trace_last_week)
   .with_associated_input(master_psf_task, [ master_psf_class ], match_rules=match_master_psf_last_day)
   .with_associated_input(master_wave_task, [ master_wave_class ], match_rules=match_master_wave_last_day)
   .with_associated_input(master_fibre_flat_task, [ master_fibre_flat_class ], min_ret=0,
                          match_rules=match_master_fibre_flat_last_week)
-  .with_associated_input(ob_wave_task, [ ob_wave_class ], min_ret=0, match_rules=match_ob)
-  .with_associated_input(ob_fibre_flat_task, [ ob_fibre_flat_class ], min_ret=0, match_rules=match_ob)
   .with_associated_input(sky_fibre_flat_task, [ sky_fibre_flat_class ], min_ret=0)
   .with_associated_input(sensitivity_ds, min_ret=0)
-  .with_meta_targets([QC0, SCIENCE])
+  .with_meta_targets([QC0, SCIENCE, CALCHECKER])
   .build())
